<!DOCTYPE html>
<!--htmlタグのlang属性を適切に出力するためのテンプレートタグ-->
<html <?php language_attributes(); ?>>

<head>
    <!--metaタグのcharset属性を適切に出力するためのテンプレートタグ-->
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <?php if (is_single()) : ?>
        <!--基本的なメタデータ-->
        <!--サイト名-->
        <meta property="og:site_name" content="<?php bloginfo('name'); ?>">
        <!--言語の種類-->
        <meta property="og:locale" content="ja_JP">
        <!--ページの種類-->
        <meta property="og:type" content="article">
        <!--ページのタイトル-->
        <meta property="og:title" content="<?php the_title(); ?>">
        <!--ページのURL-->
        <meta property="og:url" content="<?php the_permalink(); ?>">
        <!--ページの抜粋-->
        <meta property="og:description" content="<?php echo esc_attr(wp_strip_all_tags(get_the_excerpt())); ?>">

        <?php if (has_post_thumbnail()) : ?>
            <!--アイキャッチ画像のメタデータ-->
            <?php $myimg = get_post_thumbnail_id(); ?>
            <!--アイキャッチ画像のURL-->
            <meta property="og:image" content="<?php echo esc_url(wp_get_attachment_url($myimg)); ?>">
            <!--アイキャッチ画像の横幅-->
            <meta property="og:image:width" content="<?php echo esc_attr(wp_get_attachment_metadata($myimg)['width']); ?>">
            <!--アイキャッチ画像の高さ-->
            <meta property="og:image:height" content="<?php echo esc_attr(wp_get_attachment_metadata($myimg)['height']); ?>">
        <?php endif; ?>

        <!--Twitterでシェアされた記事の画像を大きく表示-->
        <meta name="twitter:card" content="summary_large_image">
        <!--Facebookと連携するためのアプリIDの記述-->
        <!--<meta property="fb:app_id" content="">-->
    <?php endif; ?>

    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
    <?php wp_body_open(); ?>

    <header class="myhead mycontainer">
        <!--ブロックエディタが幅広表示の場合にフロントのヘッダーも幅広に-->
        <div class="alignwide">
            <a href="<?php echo esc_url(home_url('/')) ?>">
                <?php bloginfo('name'); ?>
            </a>
            <p><?php bloginfo('description'); ?></p>
        </div>
    </header>

    <!--ナビゲーションメニュー-->
    <?php if (has_nav_menu('primary')) : ?>
        <nav class="mynav">
            <div class="mycontainer">
                <div class="alignwide">
                    <?php wp_nav_menu(array(
                        'theme_location' => 'primary',
                    )); ?>
                </div>
            </div>
        </nav>
    <?php endif ?>

    <!--コンテンツ部分とメニュー部分をマークアップした親要素、段組み変更用-->
    <div <?php if (current_theme_supports('mycols') && !is_front_page()) : ?> class="mycols" <?php endif; ?>>
        <!--コンテンツ部分をマークアップした親要素-->
        <div class="mycontent">
